/*
 * Copyright (c) 2006 Frederic Camps
 * Copyright (c) 2006-2009 CNRS/LAAS
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <errno.h>
#include <fcntl.h>
#include <netdb.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#include <GPSNovatel/sampleAPI.h>
#include "serial.h"
#include "logData.h"

/*!
  @brief Initialisation du GPS par un programme externe - > module Genom


 @param
*/
int
initGPS(char *serialCOM, int VMIN, int VTIME, int serialSpeed)
{
	int fd;
	char command[256];

	// Ouverture du port serie en mode non bloquant avec VTIME et VTIME
	// D'abord on essaie d'ouvrir a 9600bps, et de passer le GPS a la vitesse souhaitee
	if( (fd = openSerial(serialCOM, VMIN, VTIME, 9600)) != -1)
	{
		snprintf(command, sizeof(command),
		    "COM COM1 %d\n", serialSpeed);
		writeSerial(fd, command);
		sync();
		close(fd);
	}
	// Ensuite on l'ouvre a la bonne vitesse
	fd = openSerial(serialCOM, VMIN, VTIME, serialSpeed);
	return fd;
}

/*!
  @brief Lecture des donnes GPS par un prog externe -> module Genom


 @param
*/
int
getGPSData(int fd, int* nbTrame)
{
	int ret = readSerial(fd, nbTrame);
	return ret;
}

/*!
  @brief Envoi de commande au GPS
*/

int
putGPSCommand(int fd, char *buf)
{
	return writeSerial(fd, buf);
}

/*!
  @brief init/reinit the log infos : filename, format

 @param
*/
void
initLog(GPSNovatel_FLAG _verbose, GPSNovatel_FLAG logToFile, char *logFile, GPS_LOG_FORMAT _format) {
  if (logToFile)
	  GPSNovatel_setLogData(_verbose, 1, logFile, _format);
}

void
logData(void) {
	GPSNovatel_logData();
}

void
endGPS(GPSNovatel_FLAG logToFile) {
	/* end the log function in the GPSNovatel lib*/
	if (logToFile)
		GPSNovatel_endLogData();
}
